Struct ZwpTabletV2

pub struct ZwpTabletV2 { /* private fields */ }
Available on crate feature wayland and Linux only.
graphics tablet device

The zwp_tablet_v2 interface represents one graphics tablet device. The tablet interface itself does not generate events; all events are generated by zwp_tablet_tool_v2 objects when in proximity above a tablet.

A tablet has a number of static characteristics, e.g. device name and pid/vid. These capabilities are sent in an event sequence after the zwp_tablet_seat_v2.tablet_added event. This initial event sequence is terminated by a zwp_tablet_v2.done event.

See also the Request enum for this interface.

Implementations



impl ZwpTabletV2

pub fn name(&self, name: String)

tablet device name

A descriptive name for the tablet device.

If the device has no descriptive name, this event is not sent.

This event is sent in the initial burst of events before the zwp_tablet_v2.done event.

pub fn id(&self, vid: u32, pid: u32)

tablet device vendor/product id

The vendor and product IDs for the tablet device.

The interpretation of the id depends on the zwp_tablet_v2.bustype. Prior to version v2 of this protocol, the id was implied to be a USB vendor and product ID. If no zwp_tablet_v2.bustype is sent, the ID is to be interpreted as USB vendor and product ID.

If the device has no vendor/product ID, this event is not sent. This can happen for virtual devices or non-USB devices, for instance.

This event is sent in the initial burst of events before the zwp_tablet_v2.done event.

pub fn path(&self, path: String)

path to the device

A system-specific device path that indicates which device is behind this zwp_tablet_v2. This information may be used to gather additional information about the device, e.g. through libwacom.

A device may have more than one device path. If so, multiple zwp_tablet_v2.path events are sent. A device may be emulated and not have a device path, and in that case this event will not be sent.

The format of the path is unspecified, it may be a device node, a sysfs path, or some other identifier. It is up to the client to identify the string provided.

This event is sent in the initial burst of events before the zwp_tablet_v2.done event.

pub fn done(&self)

tablet description events sequence complete

This event is sent immediately to signal the end of the initial burst of descriptive events. A client may consider the static description of the tablet to be complete and finalize initialization of the tablet.

pub fn removed(&self)

tablet removed event

Sent when the tablet has been removed from the system. When a tablet is removed, some tools may be removed.

When this event is received, the client must zwp_tablet_v2.destroy the object.

pub fn bustype(&self, bustype: Bustype)

tablet device bus type

The bustype argument is one of the BUS_ defines in the Linux kernel’s linux/input.h

If the device has no known bustype or the bustype cannot be queried, this event is not sent.

This event is sent in the initial burst of events before the zwp_tablet_v2.done event.